@@ -242,13 +242,11 @@ class BaseVideoExtractor:
                 self.target_dimensions = self.video_dimensions
 
     def __str__(self) -> str:
-        start_time_display = f"{utils.seconds_to_timestamp(self.start_second)} | {self.start_second} seconds"
-        stop_time_display = f"{utils.seconds_to_timestamp(self.stop_second)} | {self.stop_second} seconds"
+        start_time_display = f"{utils.seconds_to_timestamp(int(self.start_second))} | {self.start_second} seconds"
+        stop_time_display = f"{utils.seconds_to_timestamp(int(self.stop_second))} | {self.stop_second} seconds"
         if self.emoji:
             start_time_display = f"{C.EMOJI_MAP['start']} {start_time_display}"
-            stop_time_display = (
-                f"{C.EMOJI_MAP['stop']} {stop_time_display}"
-            )
+            stop_time_display = f"{C.EMOJI_MAP['stop']} {stop_time_display}"
 
         return dedent(
             f"""
@@ -373,7 +371,7 @@ class VideoToImages(BaseVideoExtractor):
 
         return super().__str__() + dedent(
             f"""
-            {"IMAGE" if not self.emoji else C.EMOJI_MAP['image']}
+            {"IMAGES" if not self.emoji else C.EMOJI_MAP['image']}
               filenames:    {name_display!r}
               format:       {self.image_format!r}
               resize:       {resize_display}
